@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,9 +24,6 @@ tf_compat.ensure_tf_install()
 # pylint:disable=g-import-not-at-top
 
 from tensorflow_datasets.core import community  # pylint: disable=g-bad-import-order
-
-from tensorflow_datasets.core.constants import add_data_dir
-
 from tensorflow_datasets.core.dataset_builder import BeamBasedBuilder
 from tensorflow_datasets.core.dataset_builder import BuilderConfig
 from tensorflow_datasets.core.dataset_builder import DatasetBuilder
@@ -37,6 +34,8 @@ from tensorflow_datasets.core.dataset_info import DatasetInfo
 from tensorflow_datasets.core.dataset_info import Metadata
 from tensorflow_datasets.core.dataset_info import MetadataDict
 
+from tensorflow_datasets.core.file_adapters import FileFormat
+
 from tensorflow_datasets.core.lazy_imports_lib import lazy_imports
 
 from tensorflow_datasets.core.read_only_builder import builder_from_directory
@@ -45,18 +44,18 @@ from tensorflow_datasets.core.registered import DatasetNotFoundError
 
 from tensorflow_datasets.core.split_builder import SplitGeneratorLegacy as SplitGenerator
 
+from tensorflow_datasets.core.splits import ReadInstruction
 from tensorflow_datasets.core.splits import Split
 from tensorflow_datasets.core.splits import SplitDict
 from tensorflow_datasets.core.splits import SplitInfo
 from tensorflow_datasets.core.splits import SubSplitInfo
 
-from tensorflow_datasets.core.tfrecords_reader import ReadInstruction
-
 from tensorflow_datasets.core.utils import Experiment
 from tensorflow_datasets.core.utils import gcs_path
 from tensorflow_datasets.core.utils import tfds_path
 from tensorflow_datasets.core.utils import Version
 from tensorflow_datasets.core.utils.benchmark import BenchmarkResult
+from tensorflow_datasets.core.utils.file_utils import add_data_dir
 from tensorflow_datasets.core.utils.generic_path import as_path
 from tensorflow_datasets.core.utils.type_utils import PathLike
 from tensorflow_datasets.core.utils.type_utils import ReadOnlyPath
@@ -80,6 +79,7 @@ __all__ = [
     "DatasetInfo",
     "DatasetNotFoundError",
     "Experiment",
+    "FileFormat",
     "GeneratorBasedBuilder",
     "gcs_path",
     "lazy_imports",
