@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,14 +15,16 @@
 
 """Tests for tensorflow_datasets.core.dataset_builder."""
 
+import dataclasses
 import os
 import tempfile
 from unittest import mock
 
-import dataclasses
+from absl.testing import parameterized
+
 import dill
 import numpy as np
-import tensorflow.compat.v2 as tf
+import tensorflow as tf
 from tensorflow_datasets import testing
 from tensorflow_datasets.core import constants
 from tensorflow_datasets.core import dataset_builder
@@ -33,10 +35,9 @@ from tensorflow_datasets.core import features
 from tensorflow_datasets.core import load
 from tensorflow_datasets.core import splits as splits_lib
 from tensorflow_datasets.core import utils
+from tensorflow_datasets.core.utils import file_utils
 from tensorflow_datasets.core.utils import read_config as read_config_lib
 
-tf.enable_v2_behavior()
-
 DummyDatasetSharedGenerator = testing.DummyDatasetSharedGenerator
 
 
@@ -385,7 +386,7 @@ class DatasetBuilderMultiDirTest(testing.TestCase):
   def setUp(self):
     super(DatasetBuilderMultiDirTest, self).setUp()
     # Sanity check to make sure that no dir is registered
-    self.assertEmpty(constants._registered_data_dir)
+    self.assertEmpty(file_utils._registered_data_dir)
     # Create a new temp dir
     self.other_data_dir = os.path.join(self.get_temp_dir(), "other_dir")
     # Overwrite the default data_dir (as files get created)
@@ -396,7 +397,7 @@ class DatasetBuilderMultiDirTest(testing.TestCase):
   def tearDown(self):
     super(DatasetBuilderMultiDirTest, self).tearDown()
     # Restore to the default `_registered_data_dir`
-    constants._registered_data_dir = set()
+    file_utils._registered_data_dir = set()
     # Clear-up existing dirs
     if tf.io.gfile.exists(self.other_data_dir):
       tf.io.gfile.rmtree(self.other_data_dir)
@@ -425,7 +426,7 @@ class DatasetBuilderMultiDirTest(testing.TestCase):
     # No data_dir is passed
     # Multiple data_dirs are registered
     # -> use default path
-    constants.add_data_dir(self.other_data_dir)
+    file_utils.add_data_dir(self.other_data_dir)
     self.assertBuildDataDir(
         self.builder._build_data_dir(None), self.default_data_dir)
 
@@ -434,7 +435,7 @@ class DatasetBuilderMultiDirTest(testing.TestCase):
     # Multiple data_dirs are registered
     # Data dir contains old versions
     # -> use default path
-    constants.add_data_dir(self.other_data_dir)
+    file_utils.add_data_dir(self.other_data_dir)
     tf.io.gfile.makedirs(
         os.path.join(self.other_data_dir, "dummy_dataset_shared_generator",
                      "0.1.0"))
@@ -449,7 +450,7 @@ class DatasetBuilderMultiDirTest(testing.TestCase):
     # Multiple data_dirs are registered
     # Data found
     # -> Re-load existing data
-    constants.add_data_dir(self.other_data_dir)
+    file_utils.add_data_dir(self.other_data_dir)
     tf.io.gfile.makedirs(
         os.path.join(self.other_data_dir, "dummy_dataset_shared_generator",
                      "1.0.0"))
@@ -458,7 +459,7 @@ class DatasetBuilderMultiDirTest(testing.TestCase):
 
   def test_default_multi_dir_duplicate(self):
     # If two data dirs contains the dataset, raise an error...
-    constants.add_data_dir(self.other_data_dir)
+    file_utils.add_data_dir(self.other_data_dir)
     tf.io.gfile.makedirs(
         os.path.join(self.default_data_dir, "dummy_dataset_shared_generator",
                      "1.0.0"))
@@ -471,7 +472,7 @@ class DatasetBuilderMultiDirTest(testing.TestCase):
   def test_expicit_multi_dir(self):
     # If two data dirs contains the same version
     # Data dir is explicitly passed
-    constants.add_data_dir(self.other_data_dir)
+    file_utils.add_data_dir(self.other_data_dir)
     tf.io.gfile.makedirs(
         os.path.join(self.default_data_dir, "dummy_dataset_shared_generator",
                      "1.0.0"))
@@ -483,7 +484,7 @@ class DatasetBuilderMultiDirTest(testing.TestCase):
 
   def test_load_data_dir(self):
     """Ensure that `tfds.load` also supports multiple data_dir."""
-    constants.add_data_dir(self.other_data_dir)
+    file_utils.add_data_dir(self.other_data_dir)
 
     class MultiDirDataset(DummyDatasetSharedGenerator):  # pylint: disable=unused-variable
       VERSION = utils.Version("1.2.0")
@@ -603,6 +604,25 @@ class BuilderRestoreGcsTest(testing.TestCase):
     self.patch_gcs.start()
 
 
+class DatasetBuilderGenerateModeTest(testing.TestCase):
+
+  @classmethod
+  def setUpClass(cls):
+    super(DatasetBuilderGenerateModeTest, cls).setUpClass()
+
+  def test_reuse_cache_if_exists(self):
+    with testing.tmp_dir(self.get_temp_dir()) as tmp_dir:
+      builder = testing.DummyMnist(data_dir=tmp_dir)
+      dl_config = download.DownloadConfig(max_examples_per_split=3)
+      builder.download_and_prepare(download_config=dl_config)
+
+      dl_config = download.DownloadConfig(
+          download_mode=download.GenerateMode.REUSE_CACHE_IF_EXISTS,
+          max_examples_per_split=5)
+      builder.download_and_prepare(download_config=dl_config)
+      self.assertEqual(builder.info.splits["train"].num_examples, 5)
+
+
 class DatasetBuilderReadTest(testing.TestCase):
 
   @classmethod
@@ -661,13 +681,6 @@ class DatasetBuilderReadTest(testing.TestCase):
     ds = self.builder.as_dataset(split=splits_lib.Split.TRAIN, batch_size=2)
     self.assertEqual(1, len(tf.compat.v1.data.get_output_shapes(ds)["x"]))
 
-  @testing.run_in_graph_and_eager_modes()
-  def test_supervised_keys(self):
-    x, _ = dataset_utils.as_numpy(
-        self.builder.as_dataset(
-            split=splits_lib.Split.TRAIN, as_supervised=True, batch_size=-1))
-    self.assertEqual(x.shape[0], 20)
-
   def test_autocache(self):
     # All the following should cache
 
@@ -727,6 +740,81 @@ class DatasetBuilderReadTest(testing.TestCase):
     self.assertEqual(0, len(tf.compat.v1.data.get_output_shapes(ds)["x"]))
 
 
+class DummyDatasetWithSupervisedKeys(DummyDatasetSharedGenerator):
+
+  def __init__(self, *args, supervised_keys=None, **kwargs):
+    self.supervised_keys = supervised_keys
+    super().__init__(*args, **kwargs)
+
+  def _info(self):
+    return dataset_info.DatasetInfo(
+        builder=self,
+        features=features.FeaturesDict({"x": tf.int64}),
+        supervised_keys=self.supervised_keys,
+    )
+
+
+class DatasetBuilderAsSupervisedTest(parameterized.TestCase, testing.TestCase):
+
+  @classmethod
+  def setUpClass(cls):
+    super().setUpClass()
+    cls._tfds_tmp_dir = testing.make_tmp_dir()
+    builder = DummyDatasetWithSupervisedKeys(data_dir=cls._tfds_tmp_dir)
+    builder.download_and_prepare()
+
+  @classmethod
+  def tearDownClass(cls):
+    super().tearDownClass()
+    testing.rm_tmp_dir(cls._tfds_tmp_dir)
+
+  @testing.run_in_graph_and_eager_modes()
+  def test_supervised_keys_basic(self):
+    self.builder = DummyDatasetWithSupervisedKeys(
+        data_dir=self._tfds_tmp_dir, supervised_keys=("x", "x"))
+    x, _ = dataset_utils.as_numpy(
+        self.builder.as_dataset(
+            split=splits_lib.Split.TRAIN, as_supervised=True, batch_size=-1))
+    self.assertEqual(x.shape[0], 20)
+
+  def test_supervised_keys_triple(self):
+    self.builder = DummyDatasetWithSupervisedKeys(
+        data_dir=self._tfds_tmp_dir, supervised_keys=("x", "x", "x"))
+    result = dataset_utils.as_numpy(
+        self.builder.as_dataset(
+            split=splits_lib.Split.TRAIN, as_supervised=True, batch_size=-1))
+    self.assertLen(result, 3)
+    self.assertEqual(result[0].shape[0], 20)
+
+  def test_supervised_keys_nested(self):
+    self.builder = DummyDatasetWithSupervisedKeys(
+        data_dir=self._tfds_tmp_dir,
+        supervised_keys=("x", ("x", ("x", "x")), {
+            "a": "x",
+            "b": ("x",)
+        }))
+    single, pair, a_dict = dataset_utils.as_numpy(
+        self.builder.as_dataset(
+            split=splits_lib.Split.TRAIN, as_supervised=True, batch_size=-1))
+    self.assertEqual(single.shape[0], 20)
+    self.assertLen(pair, 2)
+    self.assertEqual(pair[1][1].shape[0], 20)
+    self.assertLen(a_dict, 2)
+    self.assertEqual(a_dict["b"][0].shape[0], 20)
+
+  @parameterized.named_parameters(
+      ("not_a_tuple", "x", "tuple of 2 or 3"),
+      ("wrong_length_tuple", ("x", "x", "x", "x", "x"), "tuple of 2 or 3"),
+      ("wrong_nested_type", ("x", ["x", "x"]), "tuple, dict, str"),
+  )
+  def test_bad_supervised_keys(self, supervised_keys, error_message):
+    with self.assertRaisesRegex(ValueError, error_message):
+      self.builder = DummyDatasetWithSupervisedKeys(
+          data_dir=self._tfds_tmp_dir,
+          # Not a tuple
+          supervised_keys=supervised_keys)
+
+
 
 
 class NestedSequenceBuilder(dataset_builder.GeneratorBasedBuilder):
