@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,7 +15,7 @@
 
 """To deserialize bytes (Example) to tf.Example."""
 
-import tensorflow.compat.v2 as tf
+import tensorflow as tf
 from tensorflow_datasets.core import utils
 
 
@@ -25,22 +25,9 @@ class ExampleParser(object):
   def __init__(self, example_specs):
     self._example_specs = example_specs
     self._flat_example_specs = utils.flatten_nest_dict(self._example_specs)
-
-  def _build_feature_specs(self):
-    """Returns the `tf.train.Example` feature specification.
-
-    Returns:
-      The `dict` of `tf.io.FixedLenFeature`, `tf.io.VarLenFeature`, ...
-    """
-
-    # Convert individual fields into tf.train.Example compatible format
-    def build_single_spec(k, v):
-      with utils.try_reraise(f"Specification error for feature {k!r} ({v}): "):
-        return _to_tf_example_spec(v)
-
-    return {
-        k: build_single_spec(k, v) for k, v in self._flat_example_specs.items()
-    }
+    self._nested_feature_specs = _build_feature_specs(self._flat_example_specs)
+    self._flat_feature_specs = utils.flatten_nest_dict(
+        self._nested_feature_specs)
 
   def parse_example(self, serialized_example):
     """Deserialize a single `tf.train.Example` proto.
@@ -59,8 +46,6 @@ class ExampleParser(object):
       example: A nested `dict` of `tf.Tensor` values. The structure and tensors
         shape/dtype match the  `example_specs` provided at construction.
     """
-    nested_feature_specs = self._build_feature_specs()
-
     # Because of RaggedTensor specs, feature_specs can be a 2-level nested dict,
     # so have to wrap `tf.io.parse_single_example` between
     # `flatten_nest_dict`/`pack_as_nest_dict`.
@@ -71,12 +56,11 @@ class ExampleParser(object):
     #         'ragged_row_lengths_0', tf.io.FixedLenSequenceFeature(...),
     #     },
     # }
-    flat_feature_specs = utils.flatten_nest_dict(nested_feature_specs)
     example = tf.io.parse_single_example(
         serialized=serialized_example,
-        features=flat_feature_specs,
+        features=self._flat_feature_specs,
     )
-    example = utils.pack_as_nest_dict(example, nested_feature_specs)
+    example = utils.pack_as_nest_dict(example, self._nested_feature_specs)
 
     example = {  # pylint:disable=g-complex-comprehension
         k: _deserialize_single_field(example_data, tensor_info)
@@ -89,6 +73,24 @@ class ExampleParser(object):
     return example
 
 
+def _build_feature_specs(flat_example_specs):
+  """Returns the `tf.train.Example` feature specification.
+
+  Args:
+    flat_example_specs: flattened example specs.
+
+  Returns:
+    The `dict` of `tf.io.FixedLenFeature`, `tf.io.VarLenFeature`, ...
+  """
+
+  # Convert individual fields into tf.train.Example compatible format
+  def build_single_spec(k, v):
+    with utils.try_reraise(f"Specification error for feature {k!r} ({v}): "):
+      return _to_tf_example_spec(v)
+
+  return {k: build_single_spec(k, v) for k, v in flat_example_specs.items()}
+
+
 def _deserialize_single_field(example_data, tensor_info):
   """Reconstruct the serialized field."""
   # Ragged tensor case:
@@ -101,7 +103,7 @@ def _deserialize_single_field(example_data, tensor_info):
     example_data = tf.reshape(example_data, shape)
 
   # Restore dtype
-  if example_data.dtype != tensor_info.dtype:
+  if not utils.is_same_tf_dtype(example_data.dtype, tensor_info.dtype):
     example_data = tf.dtypes.cast(example_data, tensor_info.dtype)
   return example_data
 
