@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,13 +15,16 @@
 
 """FeatureDict: Main feature connector container."""
 
-import six
-import tensorflow.compat.v2 as tf
+from typing import Dict, Union
+
+import tensorflow as tf
 
 from tensorflow_datasets.core import utils
 from tensorflow_datasets.core.features import feature as feature_lib
 from tensorflow_datasets.core.features import tensor_feature
 from tensorflow_datasets.core.features import top_level_feature
+from tensorflow_datasets.core.proto import feature_pb2
+from tensorflow_datasets.core.utils import py_utils
 from tensorflow_datasets.core.utils import type_utils
 
 Json = type_utils.Json
@@ -107,7 +110,7 @@ class FeaturesDict(top_level_feature.TopLevelFeature):
 
   """
 
-  def __init__(self, feature_dict):
+  def __init__(self, feature_dict: Dict[str, feature_lib.FeatureConnectorArg]):
     """Initialize the features.
 
     Args:
@@ -160,6 +163,7 @@ class FeaturesDict(top_level_feature.TopLevelFeature):
     lines.append('})')
     return '\n'.join(lines)
 
+  @py_utils.memoize()
   def get_tensor_info(self):
     """See base class for details."""
     return {
@@ -167,6 +171,7 @@ class FeaturesDict(top_level_feature.TopLevelFeature):
         for feature_key, feature in self._feature_dict.items()
     }
 
+  @py_utils.memoize()
   def get_serialized_info(self):
     """See base class for details."""
     return {
@@ -175,16 +180,26 @@ class FeaturesDict(top_level_feature.TopLevelFeature):
     }
 
   @classmethod
-  def from_json_content(cls, value: Json) -> 'FeaturesDict':
-    return cls({
-        k: feature_lib.FeatureConnector.from_json(v) for k, v in value.items()
-    })
+  def from_json_content(
+      cls, value: Union[Json, feature_pb2.FeaturesDict]) -> 'FeaturesDict':
+    if isinstance(value, dict):
+      features = {
+          k: feature_lib.FeatureConnector.from_json(v)
+          for k, v in value.items()
+      }
+    else:
+      features = {
+          name: feature_lib.FeatureConnector.from_proto(proto)
+          for name, proto in value.features.items()
+      }
+    return cls(features)
 
-  def to_json_content(self) -> Json:
-    return {
-        feature_key: feature.to_json()
-        for feature_key, feature in self._feature_dict.items()
-    }
+  def to_json_content(self) -> feature_pb2.FeaturesDict:
+    return feature_pb2.FeaturesDict(
+        features={
+            feature_key: feature.to_proto()
+            for feature_key, feature in self._feature_dict.items()
+        },)
 
   def encode_example(self, example_dict):
     """See base class for details."""
@@ -236,7 +251,7 @@ class FeaturesDict(top_level_feature.TopLevelFeature):
   def save_metadata(self, data_dir, feature_name=None):
     """See base class for details."""
     # Recursively save all child features
-    for feature_key, feature in six.iteritems(self._feature_dict):
+    for feature_key, feature in self._feature_dict.items():
       feature_key = feature_key.replace('/', '.')
       if feature_name:
         feature_key = '-'.join((feature_name, feature_key))
@@ -245,14 +260,14 @@ class FeaturesDict(top_level_feature.TopLevelFeature):
   def load_metadata(self, data_dir, feature_name=None):
     """See base class for details."""
     # Recursively load all child features
-    for feature_key, feature in six.iteritems(self._feature_dict):
+    for feature_key, feature in self._feature_dict.items():
       feature_key = feature_key.replace('/', '.')
       if feature_name:
         feature_key = '-'.join((feature_name, feature_key))
       feature.load_metadata(data_dir, feature_name=feature_key)
 
 
-def to_feature(value):
+def to_feature(value: feature_lib.FeatureConnectorArg):
   """Convert the given value to Feature if necessary."""
   if isinstance(value, feature_lib.FeatureConnector):
     return value
