@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,13 +21,14 @@ from typing import Any, Optional, Tuple, Type
 
 import tensorflow as tf
 
-from tensorflow_datasets.core import constants
 from tensorflow_datasets.core import dataset_builder
 from tensorflow_datasets.core import dataset_info
 from tensorflow_datasets.core import naming
 from tensorflow_datasets.core import registered
 from tensorflow_datasets.core import utils
 from tensorflow_datasets.core.features import feature as feature_lib
+from tensorflow_datasets.core.proto import dataset_info_pb2
+from tensorflow_datasets.core.utils import file_utils
 from tensorflow_datasets.core.utils import version as version_lib
 
 
@@ -35,38 +36,36 @@ class ReadOnlyBuilder(
     dataset_builder.FileReaderBuilder, skip_registration=True):
   """Generic DatasetBuilder loading from a directory."""
 
-  def __init__(self, builder_dir: utils.PathLike):
+  def __init__(self,
+               builder_dir: utils.PathLike,
+               *,
+               info_proto: Optional[dataset_info_pb2.DatasetInfo] = None):
     """Constructor.
 
     Args:
       builder_dir: Directory of the dataset to load (e.g.
         `~/tensorflow_datasets/mnist/3.0.0/`)
+      info_proto: DatasetInfo describing the name, config, etc of the requested
+        dataset. Note that this overwrites dataset info that may be present in
+        builder_dir.
 
     Raises:
       FileNotFoundError: If the builder_dir does not exists.
     """
     builder_dir = os.path.expanduser(builder_dir)
-    info_path = os.path.join(builder_dir, dataset_info.DATASET_INFO_FILENAME)
-    if not tf.io.gfile.exists(info_path):
-      raise FileNotFoundError(
-          f'Could not load `ReadOnlyBuilder`: {info_path} does not exists.')
+    if not info_proto:
+      info_proto = dataset_info.read_proto_from_builder_dir(builder_dir)
+    self._info_proto = info_proto
 
-    # Restore name, config, info
-    info_proto = dataset_info.read_from_json(info_path)
     self.name = info_proto.name
     self.VERSION = version_lib.Version(info_proto.version)  # pylint: disable=invalid-name
+    self.RELEASE_NOTES = info_proto.release_notes or {}  # pylint: disable=invalid-name
     if info_proto.module_name:
       # Overwrite the module so documenting `ReadOnlyBuilder` point to the
       # original source code.
       self.__module__ = info_proto.module_name
-    if info_proto.config_name:
-      builder_config = dataset_builder.BuilderConfig(
-          name=info_proto.config_name,
-          description=info_proto.config_description,
-          version=info_proto.version or None,
-      )
-    else:
-      builder_config = None
+
+    builder_config = dataset_builder.BuilderConfig.from_dataset_info(info_proto)
     # __init__ will call _build_data_dir, _create_builder_config,
     # _pick_version to set the data_dir, config, and version
     super().__init__(
@@ -81,7 +80,7 @@ class ReadOnlyBuilder(
 
     if self.info.features is None:
       raise ValueError(
-          f'Cannot restore {self.info.full_name}. It likelly mean the dataset '
+          f'Cannot restore {self.info.full_name}. It likely means the dataset '
           'was generated with an old TFDS version (<=3.2.1).')
 
   def _create_builder_config(
@@ -96,7 +95,7 @@ class ReadOnlyBuilder(
     return data_dir, data_dir  # _data_dir_root, _data_dir are builder_dir.
 
   def _info(self) -> dataset_info.DatasetInfo:
-    return dataset_info.DatasetInfo(builder=self)
+    return dataset_info.DatasetInfo.from_proto(self, self._info_proto)
 
   def _download_and_prepare(self, **kwargs):  # pylint: disable=arguments-differ
     # DatasetBuilder.download_and_prepare is a no-op as self.data_dir already
@@ -108,12 +107,12 @@ def builder_from_directory(
     builder_dir: utils.PathLike,) -> dataset_builder.DatasetBuilder:
   """Loads a `tfds.core.DatasetBuilder` from the given generated dataset path.
 
-  This function reconstruct the `tfds.core.DatasetBuilder` without
-  requirering the original generation code.
+  Reconstructs the `tfds.core.DatasetBuilder` without requiring the original
+  generation code.
 
-  It will read the `<builder_dir>/features.json` in order to infer the
-  structure (feature names, nested dict,...) and content (image, sequence,...)
-  of the dataset. The serialization format is defined in
+  From `<builder_dir>/features.json` it infers the structure (feature names,
+  nested dict,...) and content (image, sequence,...) of the dataset. The
+  serialization format is defined in
   `tfds.features.FeatureConnector` in `to_json()`.
 
   Note: This function only works for datasets generated with TFDS `4.0.0` or
@@ -129,17 +128,42 @@ def builder_from_directory(
   return ReadOnlyBuilder(builder_dir=builder_dir)
 
 
+def builder_from_metadata(
+    builder_dir: utils.PathLike,
+    info_proto: dataset_info_pb2.DatasetInfo) -> dataset_builder.DatasetBuilder:
+  """Loads a `tfds.core.DatasetBuilder` from the given metadata.
+
+  Reconstructs the `tfds.core.DatasetBuilder` without requiring the original
+  generation code. The given `info_proto` overrides whatever dataset info is in
+  `builder_dir`.
+
+  The dataset structure (feature names, nested dict,...) and content (image,
+  sequence, ...) is used from the given DatasetInfo.
+
+  Args:
+    builder_dir: path of the directory containing the dataset to read (e.g.
+      `~/tensorflow_datasets/mnist/3.0.0/`). Dataset info in this folder is
+      overridden by the `info_proto`.
+    info_proto: DatasetInfo describing the name, config, features, etc of the
+      requested dataset.
+
+  Returns:
+    builder: `tf.core.DatasetBuilder`, builder for dataset at the given path.
+  """
+  return ReadOnlyBuilder(builder_dir=builder_dir, info_proto=info_proto)
+
+
 def builder_from_files(
     name: str,
     **builder_kwargs: Any,
 ) -> dataset_builder.DatasetBuilder:
   """Loads a `tfds.core.DatasetBuilder` from files, auto-infering location.
 
-  This function is similar to `tfds.builder` (same signature), but create
+  This function is similar to `tfds.builder` (same signature), but creates
   the `tfds.core.DatasetBuilder` directly from files, without loading
   original generation source code.
 
-  It does not supports:
+  It does not support:
 
    * namespaces (e.g. 'kaggle:dataset')
    * config objects (`dataset/config` valid, but not `config=MyConfig()`)
@@ -157,15 +181,14 @@ def builder_from_files(
   """
   # Find and load dataset builder.
   builder_dir = _find_builder_dir(name, **builder_kwargs)
-  if builder_dir is not None:  # A generated dataset was found on disk
-    return builder_from_directory(builder_dir)
-  else:
-    data_dirs = constants.list_data_dirs(
+  if builder_dir is None:
+    data_dirs = file_utils.list_data_dirs(
         given_data_dir=builder_kwargs.get('data_dir'))
     raise registered.DatasetNotFoundError(
         f'Could not find dataset files for: {name}. Make sure the dataset '
         f'has been generated in: {data_dirs}. If the dataset has configs, you '
         'might have to specify the config name.')
+  return builder_from_directory(builder_dir)
 
 
 def _find_builder_dir(name: str, **builder_kwargs: Any) -> Optional[str]:
@@ -175,7 +198,7 @@ def _find_builder_dir(name: str, **builder_kwargs: Any) -> Optional[str]:
 
    * If the dataset is present, but is legacy (no feature config file), None
      is returned.
-   * If the config isn't specified, the function try to infer the default
+   * If the config isn't specified, the function tries to infer the default
      config name from the original `DatasetBuilder`.
    * The function searches in all `data_dir` registered with
      `tfds.core.add_data_dir`. If the dataset exists in multiple dirs, an error
@@ -206,7 +229,7 @@ def _find_builder_dir(name: str, **builder_kwargs: Any) -> Optional[str]:
 
   # Search the dataset across all registered data_dirs
   all_builder_dirs = []
-  for current_data_dir in constants.list_data_dirs(given_data_dir=data_dir):
+  for current_data_dir in file_utils.list_data_dirs(given_data_dir=data_dir):
     builder_dir = _find_builder_dir_single_dir(
         name.name,
         data_dir=current_data_dir,
@@ -231,8 +254,8 @@ def _find_builder_dir(name: str, **builder_kwargs: Any) -> Optional[str]:
     raise ValueError(
         f'Dataset {name} detected in multiple locations: {all_builder_dirs}. '
         'Please resolve the ambiguity by explicitly setting `data_dir=`.')
-  else:
-    return next(iter(all_builder_dirs))  # List has a single element
+
+  return all_builder_dirs[0]
 
 
 def _find_builder_dir_single_dir(
@@ -242,22 +265,22 @@ def _find_builder_dir_single_dir(
     config_name: Optional[str] = None,
     version_str: Optional[str] = None,
 ) -> Optional[str]:
-  """Same as `find_builder_dir` but require explicit dir."""
+  """Same as `find_builder_dir` but requires explicit dir."""
   # Construct the `ds_name/config/` path
-  builder_dir = os.path.join(data_dir, builder_name)
+  builder_dir = utils.as_path(data_dir) / builder_name
   if not config_name:
     # If the BuilderConfig is not specified:
-    # * Either the dataset don't have config
+    # * Either the dataset doesn't have a config
     # * Either the default config should be used
     # Currently, in order to infer the default config, we are still relying on
     # the code.
     # TODO(tfds): How to avoid code dependency and automatically infer the
-    # config existance and name ?
+    # config existence and name?
     config_name = _get_default_config_name(builder_dir, builder_name)
 
   # If has config (explicitly given or default config), append it to the path
   if config_name:
-    builder_dir = os.path.join(builder_dir, config_name)
+    builder_dir = builder_dir / config_name
 
   # Extract the version
   version_str = _get_version_str(builder_dir, requested_version=version_str)
@@ -265,23 +288,23 @@ def _find_builder_dir_single_dir(
   if not version_str:  # Version not given or found
     return None
 
-  builder_dir = os.path.join(builder_dir, version_str)
+  builder_dir = builder_dir / version_str
 
-  # Check for builder dir existance
   try:
-    if not tf.io.gfile.exists(builder_dir):
-      return None
+    # Backward compatibility, in order to be a valid ReadOnlyBuilder, the folder
+    # has to contain the feature configuration.
+    builder_dir = os.fspath(builder_dir)
+    if tf.io.gfile.exists(feature_lib.make_config_path(builder_dir)):
+      return str(builder_dir)
   except tf.errors.PermissionDeniedError:
     return None
-
-  # Backward compatibility, in order to be a valid ReadOnlyBuilder, the folder
-  # has to contain the feature configuration.
-  if not tf.io.gfile.exists(feature_lib.make_config_path(builder_dir)):
-    return None
-  return builder_dir
+  return None
 
 
-def _get_default_config_name(builder_dir: str, name: str) -> Optional[str]:
+def _get_default_config_name(
+    builder_dir: utils.ReadOnlyPath,
+    name: str,
+) -> Optional[str]:
   """Returns the default config of the given dataset, None if not found."""
   # Search for the DatasetBuilder generation code
   try:
@@ -298,11 +321,11 @@ def _get_default_config_name(builder_dir: str, name: str) -> Optional[str]:
       return cls.BUILDER_CONFIGS[0].name
 
   # Otherwise, try to load default config from common metadata
-  return dataset_builder.load_default_config_name(utils.as_path(builder_dir))
+  return dataset_builder.load_default_config_name(builder_dir)
 
 
 def _get_version_str(
-    builder_dir: str,
+    builder_dir: utils.ReadOnlyPath,
     *,
     requested_version: Optional[str] = None,
 ) -> Optional[str]:
@@ -315,7 +338,7 @@ def _get_version_str(
   Returns:
     version_str: The version directory name found in `builder_dir`.
   """
-  all_versions = version_lib.list_all_versions(builder_dir)
+  all_versions = version_lib.list_all_versions(os.fspath(builder_dir))
   # Version not given, using the last one.
   if not requested_version and all_versions:
     return str(all_versions[-1])
