@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,6 +21,7 @@ import contextlib
 import distutils.version
 import functools
 import os
+from typing import Optional
 
 MIN_TF_VERSION = "2.1.0"
 
@@ -44,7 +45,7 @@ def ensure_tf_install():  # pylint: disable=g-statement-before-imports
   _ensure_tf_install_called = True
 
   try:
-    import tensorflow.compat.v2 as tf  # pylint: disable=import-outside-toplevel
+    import tensorflow as tf  # pylint: disable=import-outside-toplevel
   except ImportError:
     # Print more informative error message, then reraise.
     print("\n\n***************************************************************")
@@ -67,10 +68,35 @@ def ensure_tf_install():  # pylint: disable=g-statement-before-imports
 
 def is_dataset(ds):
   """Whether ds is a Dataset. Compatible across TF versions."""
-  import tensorflow.compat.v2 as tf  # pylint: disable=import-outside-toplevel
+  import tensorflow as tf  # pylint: disable=import-outside-toplevel
   return isinstance(ds, (tf.data.Dataset, tf.compat.v1.data.Dataset))
 
 
+def get_single_element(ds):
+  """Calls `tf.data.Dataset.get_single_element`."""
+  import tensorflow as tf  # pylint: disable=import-outside-toplevel
+  if hasattr(ds, "get_single_element"):  # tf 2.6 and above
+    return ds.get_single_element()
+  else:
+    return tf.data.experimental.get_single_element(ds)
+
+
+def _get_option_deterministic_field() -> str:
+  import tensorflow as tf  # pylint: disable=import-outside-toplevel
+  if hasattr(tf.data.Options(), "deterministic"):
+    return "deterministic"
+  return "experimental_deterministic"
+
+
+def get_option_deterministic(options) -> Optional[bool]:
+  """Returns the option whether the output should be in deterministic order."""
+  return getattr(options, _get_option_deterministic_field())
+
+
+def set_option_deterministic(options, value: bool) -> None:
+  setattr(options, _get_option_deterministic_field(), value)
+
+
 def _make_pathlike_fn(fn, nb_path_arg=1):
   """Wrap the function in a PathLike-compatible function."""
 
@@ -93,7 +119,7 @@ def mock_gfile_pathlike():
   Yields:
     None
   """
-  import tensorflow.compat.v2 as tf  # pylint: disable=import-outside-toplevel
+  import tensorflow as tf  # pylint: disable=import-outside-toplevel
   import tensorflow_datasets.testing as tfds_test  # pytype: disable=import-error
 
   class GFile(tf.io.gfile.GFile):
