@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -24,7 +24,7 @@ from typing import Any, List, Optional
 
 import numpy as np
 
-import tensorflow.compat.v2 as tf
+import tensorflow as tf
 from tensorflow_datasets.core import lazy_imports_lib
 from tensorflow_datasets.core.utils import py_utils
 from tensorflow_datasets.core.utils import resource_utils
@@ -45,7 +45,7 @@ def decode_image(image_bytes: bytes) -> np.ndarray:
   return runner.run(tf.image.decode_image, image_bytes)
 
 
-def png_to_jpeg(image_bytes: bytes, quality: int = 100) -> np.ndarray:
+def png_to_jpeg(image_bytes: bytes, quality: int = 100) -> bytes:
   """Converts PNG image (bytes or str) to JPEG (bytes)."""
   runner = _get_runner()
   decode_fn = lambda img: tf.image.decode_png(img, channels=3)
@@ -54,7 +54,7 @@ def png_to_jpeg(image_bytes: bytes, quality: int = 100) -> np.ndarray:
   return runner.run(fn, image)
 
 
-def jpeg_cmyk_to_rgb(image_bytes: bytes, quality: int = 100) -> np.ndarray:
+def jpeg_cmyk_to_rgb(image_bytes: bytes, quality: int = 100) -> bytes:
   """Converts JPEG CMYK image (bytes) to RGB JPEG (bytes)."""
   runner = _get_runner()
   image = runner.run(tf.image.decode_jpeg, image_bytes)
