@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -306,7 +306,7 @@ def test_flatten_with_path():
     ['url', 'filename'],
     [
         (
-            'http://test.com/appspot.com/tsvsWithoutLabels%2FAX.tsv?'
+            'http://test.com/appspot.com/tsvsWithoutLabels%2FAX.tsv?'  # pylint: disable=implicit-str-concat
             'Id=firebase&Expires=2498860800',
             'tsvsWithoutLabels_AX.tsv'  # `%2F` -> `_`
         ),
