@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,6 +16,7 @@
 """Image Classification datasets."""
 
 from tensorflow_datasets.image_classification.beans import Beans
+from tensorflow_datasets.image_classification.bee_dataset import BeeDataset
 from tensorflow_datasets.image_classification.bigearthnet import Bigearthnet
 from tensorflow_datasets.image_classification.binary_alpha_digits import BinaryAlphaDigits
 from tensorflow_datasets.image_classification.caltech import Caltech101
@@ -37,20 +38,24 @@ from tensorflow_datasets.image_classification.cycle_gan import CycleGAN
 from tensorflow_datasets.image_classification.deep_weeds import DeepWeeds
 from tensorflow_datasets.image_classification.diabetic_retinopathy_detection import DiabeticRetinopathyDetection
 from tensorflow_datasets.image_classification.dmlab import Dmlab
+from tensorflow_datasets.image_classification.domainnet import Domainnet
 from tensorflow_datasets.image_classification.dtd import Dtd
 from tensorflow_datasets.image_classification.eurosat import Eurosat
 from tensorflow_datasets.image_classification.flowers import TFFlowers
 from tensorflow_datasets.image_classification.food101 import Food101
 from tensorflow_datasets.image_classification.geirhos_conflict_stimuli import GeirhosConflictStimuli
 from tensorflow_datasets.image_classification.horses_or_humans import HorsesOrHumans
+from tensorflow_datasets.image_classification.i_naturalist2018 import INaturalist2018
 from tensorflow_datasets.image_classification.imagenet import Imagenet2012
 from tensorflow_datasets.image_classification.imagenet2012_corrupted import Imagenet2012Corrupted
 from tensorflow_datasets.image_classification.imagenet2012_multilabel import Imagenet2012Multilabel
 from tensorflow_datasets.image_classification.imagenet2012_real import Imagenet2012Real
 from tensorflow_datasets.image_classification.imagenet2012_subset import Imagenet2012Subset
 from tensorflow_datasets.image_classification.imagenet_a import ImagenetA
+from tensorflow_datasets.image_classification.imagenet_lt import ImagenetLt
 from tensorflow_datasets.image_classification.imagenet_r import ImagenetR
 from tensorflow_datasets.image_classification.imagenet_resized import ImagenetResized
+from tensorflow_datasets.image_classification.imagenet_sketch import ImagenetSketch
 from tensorflow_datasets.image_classification.imagenet_v2 import ImagenetV2
 from tensorflow_datasets.image_classification.imagenette import Imagenette
 from tensorflow_datasets.image_classification.imagewang import Imagewang
