@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,8 +15,11 @@
 
 """RLU datasets."""
 from tensorflow_datasets.rl_unplugged.rlu_atari import RluAtari
+from tensorflow_datasets.rl_unplugged.rlu_atari_checkpoints import RluAtariCheckpoints
+from tensorflow_datasets.rl_unplugged.rlu_atari_checkpoints_ordered import RluAtariCheckpointsOrdered
 from tensorflow_datasets.rl_unplugged.rlu_dmlab_explore_object_rewards_few import RluDmlabExploreObjectRewardsFew
 from tensorflow_datasets.rl_unplugged.rlu_dmlab_explore_object_rewards_many import RluDmlabExploreObjectRewardsMany
 from tensorflow_datasets.rl_unplugged.rlu_dmlab_rooms_select_nonmatching_object import RluDmlabRoomsSelectNonmatchingObject
 from tensorflow_datasets.rl_unplugged.rlu_dmlab_rooms_watermaze import RluDmlabRoomsWatermaze
 from tensorflow_datasets.rl_unplugged.rlu_dmlab_seekavoid_arena01 import RluDmlabSeekavoidArena01
+from tensorflow_datasets.rl_unplugged.rlu_rwrl import RluRwrl
