@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -21,6 +21,8 @@ Displayed in https://www.tensorflow.org/datasets/catalog/.
 
 import abc
 import html
+import os
+import re
 import textwrap
 from typing import List, Optional, Union
 
@@ -159,8 +161,7 @@ class SourceCodeSection(Section):
   def content(self, builder: tfds.core.DatasetBuilder):
     # TODO(tfds): Display the source code
     if isinstance(builder, tfds.core.read_only_builder.ReadOnlyBuilder):
-      return ('Missing '
-              '([#2813](https://github.com/tensorflow/datasets/issues/2813))')
+      return _get_read_only_builder_source_code_link(builder)
     class_path = tfds.core.utils.get_class_path(builder).split('.')
     del class_path[-2]
     class_path = '.'.join(class_path)
@@ -168,6 +169,44 @@ class SourceCodeSection(Section):
     return f'[`{class_path}`]({class_url})'
 
 
+def _get_read_only_builder_source_code_link(
+    builder: tfds.core.DatasetBuilder) -> str:
+  """Extract the source code for read-only builder."""
+  if 'read_only_builder' in builder.__module__:  # module unknown
+    return ('Missing (dataset generated before '
+            '[#2813](https://github.com/tensorflow/datasets/issues/2813))')
+  url_title = builder.__module__
+  module_url = 'https://github.com/tensorflow/datasets'
+  # TODO(epot): For datasets built with `tfds build` __module__ correspond
+  # to the relative path, not absolute so can't be recover.
+  return f'[{url_title}]({module_url})'
+
+
+class LocationSection(Section):
+
+  NAME = 'Path'
+
+  def get_key(self, _):
+    return True  # Always common to all configs
+
+  def content(self, builder: tfds.core.DatasetBuilder):
+    # Path is only documented for community datasets
+    if (not isinstance(builder, tfds.core.read_only_builder.ReadOnlyBuilder)
+        # If datasets have not yet been regenerated after update, even TFDS
+        # datasets can be ReadOnlyBuilder
+        or builder.__module__.startswith('tensorflow_datasets')):
+      return _SKIP_SECTION
+
+    # /.../ds/config/1.0.0/ -> /.../ds/
+    path = builder.data_path.parent
+    if builder.builder_config:
+      path = path.parent
+    path = os.fspath(path)
+
+    # Link is automatically added, so can just return the path
+    return path  # pylint: disable=protected-access
+
+
 class VersionSection(Section):
 
   NAME = 'Versions'
@@ -354,8 +393,11 @@ class SupervisedKeySection(Section):
       ' (See [`as_supervised` doc]'
       '(https://www.tensorflow.org/datasets/api_docs/python/tfds/load#args))')
 
-  def get_key(self, builder: tfds.core.DatasetBuilder):
-    return builder.info.supervised_keys
+  def get_key(self, builder: tfds.core.DatasetBuilder) -> Key:
+    # get_key() must return a Key (str/int), but supervised_keys can be a tuple
+    # or dict. Keys also need to be hashable, but dicts are mutable and tuples
+    # can contain mutable entries, so use repr as a snapshot.
+    return repr(builder.info.supervised_keys)
 
   def content(self, builder: tfds.core.DatasetBuilder):
     return f'`{str(builder.info.supervised_keys)}`'
@@ -648,6 +690,7 @@ def get_markdown_string(
       ConfigDescriptionSection(),
       HomepageSection(),
       SourceCodeSection(),
+      LocationSection(),
       VersionSection(nightly_doc_util),
       DownloadSizeSection(),
       DatasetSizeSection(),
