@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2020 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -92,7 +92,7 @@ class BigPatentConfig(tfds.core.BuilderConfig):
             "2.0.0": "Update to use cased raw strings",
             "1.0.0": "lower cased tokenized words",
         },
-        **kwargs)
+        **kwargs)  # pytype: disable=wrong-arg-types  # gen-stub-imports
     self.cpc_codes = cpc_codes
 
 
@@ -195,7 +195,7 @@ def _get_english_words():
   if not _ENGLISH_WORDS:
     nltk = tfds.core.lazy_imports.nltk
     resource_path = tfds.core.utils.resource_path(nltk)
-    data_path = str(resource_path / "nltk_data/corpora/words/en")
+    data_path = os.fspath(resource_path / "nltk_data/corpora/words/en")
     word_list = nltk.data.load(data_path, format="raw").decode("utf-8")
     _ENGLISH_WORDS = frozenset(word_list.split("\n"))
   return _ENGLISH_WORDS
