@@ -1,5 +1,5 @@
 # coding=utf-8
-# Copyright 2021 The TensorFlow Datasets Authors.
+# Copyright 2022 The TensorFlow Datasets Authors.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -22,7 +22,7 @@ import os
 import uuid
 
 from absl import logging
-import tensorflow.compat.v2 as tf
+import tensorflow as tf
 import tensorflow_datasets.public_api as tfds
 from tensorflow_datasets.text import c4_utils
 
@@ -387,7 +387,8 @@ class C4(tfds.core.BeamBasedBuilder):
         tf.io.gfile.makedirs(tmp_dir)
         downloader = tfds.download.downloader.get_downloader()
         with downloader.tqdm():
-          dl_path = downloader.download(url, tmp_dir).get().path
+          # TODO(slebedev): Investigate why pytype infers Promise[Future[...]].
+          dl_path = downloader.download(url, tmp_dir).get().path  # type: ignore
         tf.io.gfile.rename(os.fspath(dl_path), out_path, overwrite=True)
       finally:
         if tf.io.gfile.exists(tmp_dir):
